@@ -26,6 +26,7 @@ from logging import Filter, Handler, Logger
 from typing import Callable, Dict, Iterable, List, Optional, Sequence, Tuple, TypeVar, cast
 
 import fs
+from fs.base import FS
 from tqdm.auto import tqdm
 
 from .eonode import EONode
@@ -82,7 +83,7 @@ class EOExecutor:
         execution_names: Optional[List[str]] = None,
         save_logs: bool = False,
         logs_folder: str = ".",
-        filesystem: Optional[fs.base.FS] = None,
+        filesystem: Optional[FS] = None,
         logs_filter: Optional[Filter] = None,
         logs_handler_factory: _HandlerFactoryType = logging.FileHandler,
     ):
@@ -141,7 +142,7 @@ class EOExecutor:
         return execution_names
 
     @staticmethod
-    def _parse_logs_filesystem(filesystem: Optional[fs.base.FS], logs_folder: str) -> Tuple[fs.base.FS, str]:
+    def _parse_logs_filesystem(filesystem: Optional[FS], logs_folder: str) -> Tuple[FS, str]:
         """Ensures a filesystem and a file path relative to it."""
         if filesystem is None:
             return get_base_filesystem_and_path(logs_folder)
@@ -156,7 +157,7 @@ class EOExecutor:
         :param multiprocess: If `True` it will use `concurrent.futures.ProcessPoolExecutor` which will distribute
             workflow executions among multiple processors. If `False` it will use
             `concurrent.futures.ThreadPoolExecutor` which will distribute workflow among multiple threads.
-            However even when `multiprocess=False`, tasks from workflow could still be using multiple processors.
+            However, even when `multiprocess=False`, tasks from workflow could still be using multiple processors.
             This parameter is used especially because certain task cannot run with
             `concurrent.futures.ProcessPoolExecutor`.
             In case of `workers=1` this parameter is ignored and workflows will be executed consecutively.
@@ -204,7 +205,7 @@ class EOExecutor:
     def _run_execution(
         self, processing_args: List[_ProcessingData], workers: int, processing_type: _ProcessingType
     ) -> List[WorkflowResults]:
-        """Runs the execution an each item of processing_args list."""
+        """Runs the execution for each item of processing_args list."""
         if processing_type is _ProcessingType.SINGLE_PROCESS:
             return list(tqdm(map(self._execute_workflow, processing_args), total=len(processing_args)))
 
@@ -404,7 +405,7 @@ def submit_and_monitor_execution(
 
 def execute_with_mp_lock(execution_function: Callable, *args, **kwargs) -> object:
     """A helper utility function that executes a given function with multiprocessing lock if the process is being
-    executed in a multi-processing mode.
+    executed in a multiprocessing mode.
 
     :param execution_function: A function
     :param args: Function's positional arguments
