@@ -25,7 +25,7 @@ class LogFileFilter(Filter):
 
     def __init__(self, thread_name: Optional[str], *args, **kwargs):
         """
-        :param thread_name: Name of the thread by which to filter logs. By default it won't filter by any name.
+        :param thread_name: Name of the thread by which to filter logs. By default, it won't filter by any name.
         """
         self.thread_name = thread_name
         super().__init__(*args, **kwargs)
